==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedConvertBody.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedConvertBodyMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.support.processor.ConvertBodyProcessor;

@ManagedResource(description = "Managed ConvertBody")
public class ManagedConvertBody extends ManagedProcessor implements ManagedConvertBodyMBean {
    private final ConvertBodyProcessor processor;

    public ManagedConvertBody(CamelContext context, ConvertBodyProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
        this.processor = processor;
    }

    @Override
    public String getType() {
        return processor.getType().getCanonicalName();
    }

    @Override
    public String getCharset() {
        return processor.getCharset();
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedConvertBody.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedConvertBodyMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.support.processor.ConvertBodyProcessor;

@ManagedResource(description = "Managed ConvertBody")
public class ManagedConvertBody extends ManagedProcessor implements ManagedConvertBodyMBean {

    public ManagedConvertBody(CamelContext context, ConvertBodyProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
    }

    @Override
    public ConvertBodyProcessor getProcessor() {
        return (ConvertBodyProcessor) super.getProcessor();
    }

    @Override
    public String getType() {
        return getProcessor().getType().getCanonicalName();
    }

    @Override
    public String getCharset() {
        return getProcessor().getCharset();
    }
}
